# zcmds
Cross platform(ish) productivity commands written in python


[![Actions Status](https://github.com/zackees/zcmds/workflows/MacOS_Tests/badge.svg)](https://github.com/zackees/zcmds/actions/workflows/push_macos.yml)
[![Actions Status](https://github.com/zackees/zcmds/workflows/Win_Tests/badge.svg)](https://github.com/zackees/zcmds/actions/workflows/push_win.yml)
[![Actions Status](https://github.com/zackees/zcmds/workflows/Ubuntu_Tests/badge.svg)](https://github.com/zackees/zcmds/actions/workflows/push_ubuntu.yml)


# Install:

  * `python -pip install -e .`
  * Test by typing in `zcmds`
  * `zcmds_install`

# Additional install

  For the pdf2image use:
  * win32: `choco install poppler`
  * ... ?
